Overview
========
pyNlple - a library with basic NLP utils. Also includes methods and APIs for data accessing/writing.

Requirements
============

Cat `requirements.txt`

Installation
============

Run setup.py to install / `pip install pynlple`

Notes
============
- name inspired by https://www.youtube.com/watch?v=1W3sslyiUfg
- yeah, we had "PYthon" and "NLP" procedures, so...
- and yeah, try to read it as #pineapple http://www.veepy.com/wp-content/uploads/2015/05/1965.jpg

## Licenses

Install from https://pypi.org/project/pip-licenses/

```
pip install pip-licenses
```

Run 

```
make licenses
```
